aboutsummaryrefslogtreecommitdiff
path: root/build.sh
diff options
context:
space:
mode:
authorAxel Dürkop <axel.duerkop@tuhh.de>2021-02-24 16:42:55 +0100
committerAxel Dürkop <axel.duerkop@tuhh.de>2021-02-24 16:42:55 +0100
commitec57f87ca25fa993914ca5270e768ecdf42047e5 (patch)
tree1b20a0766d45bff7bdf181bc506913c61d41bdf0 /build.sh
parent0eae14415426c5a63c80ebce5bad77201a4502e3 (diff)
Update build config
Diffstat (limited to 'build.sh')
-rwxr-xr-xbuild.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/build.sh b/build.sh
index db77f9b..8729a9c 100755
--- a/build.sh
+++ b/build.sh
@@ -1,7 +1,7 @@
#!/bin/sh
-xargs -a ./content/toc.txt pandoc -H content/preamble.tex --citeproc -o build/book.pdf ./config/.pandoc-config.yml --pdf-engine=xelatex
+xargs -a ./content/toc.txt pandoc -H content/preamble.tex --citeproc -o build/book.pdf ./config/.pandoc-config.yml --pdf-engine=xelatex --template=templates/default-2.11.4.latex -B ./content/cover.tex
# Da pandoc 2.11.3 einen Bug mit einer Tabelle hat, muss ich lokal mit docker und pandoc 2.11.4 bauen
# docker run --rm -v $PWD:/data --entrypoint /bin/sh pandoc/latex:2.11.4 -c 'tlmgr install footmisc; /usr/bin/xargs -a ./content/toc.txt pandoc -H content/preamble.tex --citeproc -o build/book.pdf ./config/.pandoc-config.yml --pdf-engine=xelatex' \ No newline at end of file
@@ -1,7 +1,7 @@
# Da pandoc 2.11.3 einen Bug mit einer Tabelle hat, muss ich lokal mit docker und pandoc 2.11.4 bauen
-# docker run --rm -v $PWD:/data --entrypoint /bin/sh pandoc/latex:2.11.4 -c 'tlmgr install footmisc; /usr/bin/xargs -a ./content/toc.txt pandoc -H content/preamble.tex --citeproc -o build/book.pdf ./config/.pandoc-config.yml --pdf-engine=xelatex' \ No newline at end of file
+# docker run --rm -v $PWD:/data --entrypoint /bin/sh xldrkp/77tipps -c '/usr/bin/xargs -a ./content/toc.txt pandoc -H content/preamble.tex --citeproc -o build/book.pdf ./config/.pandoc-config.yml --pdf-engine=xelatex --template=templates/default-2.11.4.latex -B ./content/cover.tex' \ No newline at end of file